# Python库 - 妙花笔记API

> 请注意：本仓库并非由 **极核科技** 开发，故不保证其可用性，且随时可能停更

> 请注意：本仓库还未开发完成，目前功能有限

> 请注意：使用时请确保云同步处于开启状态（废话）

# 本项目使用 MIT 许可协议
## 它 *允许* 了什么？
 - 你可以 **使用、分发、修改**
 - 你可以 **免费使用** 或者 **付费出售** 这份源代码
 - 修改后闭源
 - 商业使用
## 它 *限制* 了什么？
 - **不保证** 本仓库一定能用
 - 原作者 **不为** 使用后的一切风险承担责任
## 它 *需要* 我做什么？
 - 在你的项目/应用中放置 MIT 许可协议


# 本项目版本号命名规则
开发时使用的Android软件版本 + 本项目版本

如 **0.2.24.1** 就是 基于 **0.2.24** 版本的Android妙花笔记 开发的 第 **1** 个版本 的API库

# Todo

 - [x] 登录
 - [ ] 获取笔记内容
 - [ ] 添加/修改笔记内容
 - [ ] 获取/修改云同步状态